##  Restoring a Previous Version or Saving it as New
To revert back to a previous version, do the following:
  1. In the version history panel, hover over the needed version and open the context menu by clicking on the 3 dot menu icon.
  2. Select Restore this Version. However, note that you must have write permission for the specific diagram to restore it to a previous version.
![Version history panel with context menu showing restore and save options for a previous version.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741e4d47a441014abf0e0b473a6ddee_LowRes.png)
Restoring a Previous Version or Saving it as New


Similarly, selecting Save as New allows you to save a draft or existing version as a new diagram.
